@@ -14,7 +14,6 @@
 
 #include <KMime/Message>
 
-#include <KCharsets>
 #include <QByteArray>
 #include <QDebug>
 #include <QMimeDatabase>
@@ -236,7 +235,7 @@ MessagePart::List ObjectTreeParser::collectContentParts(MessagePart::Ptr start)
         },
         [start](const MessagePart::Ptr &part) {
             if (const auto attachment = dynamic_cast<MimeTreeParser::AttachmentMessagePart *>(part.data())) {
-                return attachment->mimeType() == "text/calendar";
+                return attachment->mimeType() == QByteArrayLiteral("text/calendar");
             } else if (const auto text = dynamic_cast<MimeTreeParser::TextMessagePart *>(part.data())) {
                 auto enc = dynamic_cast<MimeTreeParser::EncryptedMessagePart *>(text->parentPart());
                 if (enc && enc->error()) {
@@ -319,7 +318,7 @@ QString ObjectTreeParser::resolveCidLinks(const QString &html)
 {
     auto text = html;
     static const auto regex = QRegularExpression(QLatin1StringView("(src)\\s*=\\s*(\"|')(cid:[^\"']+)\\2"));
-    auto it = regex.globalMatch(text);
+    auto it = regex.globalMatchView(text);
     while (it.hasNext()) {
         const auto match = it.next();
         const auto link = QUrl(match.captured(3));
@@ -433,7 +432,7 @@ MessagePart::Ptr ObjectTreeParser::parseObjectTreeInternal(KMime::Content *node,
             }
             // Fallback to the generic handler
             {
-                auto list = processType(node, mediaType, "*");
+                auto list = processType(node, mediaType, QByteArrayLiteral("*"));
                 if (!list.isEmpty()) {
                     return list;
                 }
@@ -478,8 +477,8 @@ QByteArray ObjectTreeParser::codecNameFor(KMime::Content *node) const
 
     // utf-8 is a superset of us-ascii, so we don't lose anything if we use it instead
     // utf-8 is used so widely nowadays that it is a good idea to use it to fix issues with broken clients.
-    if (charset == "us-ascii") {
-        charset = "utf-8";
+    if (charset == QByteArrayLiteral("us-ascii")) {
+        charset = QByteArrayLiteral("utf-8");
     }
     if (!charset.isEmpty()) {
         if (const QStringDecoder c(charset.constData()); c.isValid()) {
